#!/bin/bash
# small script running set of single point calculations
# to check the PW convergence
#
# (c) 2016  http://dannyvanpoucke.be

BIN="mympirun vasp533_tsD3"

for encut in {300..1000..10}; do
cat >INCAR<< EOF
general:
    SYSTEM = CO-molecule
    ISTART = 0     ! 0 start from scratch, 1 use old WAVECAR
    ICHARG = 2     ! 1 use old CHGCAR, 2 superposition atoms
                   ! 10+ Fix CHG
    ISMEAR = 0     ! -5 Tetra+Blochl, 0 Gaussian, >=1 MP
    SIGMA = 0.1    ! width smearing
    EDIFF = 1.0E-7 ! electronic convergence criterium
    PREC = High    ! used precision
    LWAVE = .FALSE.  ! do not write the WAVECAR file
    LCHARG = .FALSE.  ! write the CHGCAR file
    LVTOT = .FALSE.  ! do not write the potetial file
    ENCUT = $encut   ! kinetic energy cutoff
dynamic:
    IBRION = -1  ! -1 fix atoms, 2 ConjGrad for relax
    NSW = 0      ! number of ionic steps
parallel:
   LPLANE = .TRUE.      ! parallelize over plane waves
   NPAR = 1 ; NSIM = 8  ! 
EOF

$BIN >> out.dat
wait

E0=`grep F= OSZICAR | awk '{print sprintf("%.9f", $5); }'`
EATOMC=`grep "added to EATOM" OUTCAR | head -1 | awk '{print $6}'`
EATOMO=`grep "added to EATOM" OUTCAR | tail -1 | awk '{print $6}'`
# add the energy corrections...due to sign-convention for the EATOM contribution, 
# we need to add the values to the values to remove the correction
Ecorr=`echo $E0 + $EATOMC + $EATOMO | bc `
TIME=`grep "LOOP+" OUTCAR | awk '{print $7}'`

echo $encut" | "$E0"  "$EATOMC"  "$EATOMO"  "$Ecorr"  time= "$TIME >> PWconv.dat
rm -f INCAR

done



