#!/bin/bash
# small script running set of single point calculations
# to check the PW convergence
#
# (c) 2016  http://dannyvanpoucke.be

BIN="mympirun vasp533_tsD3"

for encut in {150..1000..10}; do
cat >INCAR<< EOF
general:
    SYSTEM = Germanium Bulk
    ISTART = 0      ! start from 0: scratch, 1: previous WAVECAR
    ICHARG = 2      ! 1: read old CHGCAR, 2: superposition from atom positions
    ISMEAR = -5     ! 0: Gaussian; 1-N: Methfessel-Paxton; -5: Tetra+Blochl
    EDIFF = 1.0E-6  ! Energy convergence criterion
    PREC = Normal   ! Low, Med, Normal, Accurate 
    ENCUT = $encut  ! kinetic energy cutoff --> plane waves
    LWAVE = .FALSE. ! write a file containing the coefficients of the wavefunctions
    LCHARG = .TRUE. ! write the charge density on a real-space grid
    LVTOT = .FALSE. ! write a file with the local potential on a real-space grid
    ISPIN = 1       ! 1:not spin-polarized  2: include spin
dynamic:
    IBRION = -1     ! -1: Fix atoms; 0: MD; 2: ConjGrad relax
    NSW = 0         ! Number electronic steps
parallel:
   LPLANE = .TRUE.      ! parallelize over plane waves
   NPAR = 1 ; NSIM = 8  ! 
EOF

$BIN >> out.dat
wait

E0=`grep F= OSZICAR | awk '{print sprintf("%.9f", $5); }'`
EATOM=`grep "added to EATOM" OUTCAR | awk '{print $6}'`
Ecorr=`echo $E0 + $EATOM*8 | bc `
TIME=`grep "LOOP+" OUTCAR | awk '{print $7}'`

echo $encut" | "$E0"  "$EATOM"  "$Ecorr"  time= "$TIME >> PWconv.dat
rm -f INCAR

done



